@@ -54,6 +54,10 @@ read_bin.spark_worker_connection <- function(con, what, n, endian = NULL) {
   read_bin_wait(con, what, n, endian)
 }
 
+read_bin.livy_backend <- function(con, what, n, endian = NULL) {
+  read_bin.default(con$rc, what, n, endian)
+}
+
 readObject <- function(con) {
   # Read type first
   type <- readType(con)
@@ -103,8 +107,10 @@ readFastStringArray <- function(con) {
 }
 
 readDateArray <- function(con, n = 1) {
-  r <- readTime(con, n)
-  if (getOption("sparklyr.collect.datechars", FALSE)) r else as.Date(r)
+  if (n == 0)
+    as.Date(NA)
+  else
+    do.call(c, lapply(seq(n), function(x) readDate(con)))
 }
 
 readInt <- function(con, n = 1) {
@@ -134,10 +140,12 @@ readType <- function(con) {
 
 readDate <- function(con) {
   date_str <- readString(con)
-  if (date_str == "")
-    NA
+  if (is.null(date_str) || identical(date_str, ""))
+    as.Date(NA)
+  else if (getOption("sparklyr.collect.datechars", FALSE))
+    date_str
   else
-    as.Date(date_str)
+    as.Date(date_str, tz = "UTC")
 }
 
 readTime <- function(con, n = 1) {
