@@ -14,9 +14,12 @@
 #' @export
 ft_index_to_string <- function(x, input_col = NULL, output_col = NULL, labels = NULL,
                                uid = random_string("index_to_string_"), ...) {
+  check_dots_used()
   UseMethod("ft_index_to_string")
 }
 
+ml_index_to_string <- ft_index_to_string
+
 #' @export
 ft_index_to_string.spark_connection <- function(x, input_col = NULL, output_col = NULL, labels = NULL,
                                                 uid = random_string("index_to_string_"), ...) {
@@ -28,13 +31,13 @@ ft_index_to_string.spark_connection <- function(x, input_col = NULL, output_col
     uid = uid
   ) %>%
     c(rlang::dots_list(...)) %>%
-    ml_validator_index_to_string()
+    validator_ml_index_to_string()
 
-  jobj <- ml_new_transformer(
+  jobj <- spark_pipeline_stage(
     x, "org.apache.spark.ml.feature.IndexToString",
     input_col = .args[["input_col"]], output_col = .args[["output_col"]], uid = .args[["uid"]]
   ) %>%
-    maybe_set_param("setLabels", .args[["labels"]])
+    jobj_set_param("setLabels", .args[["labels"]])
 
   new_ml_index_to_string(jobj)
 }
@@ -70,10 +73,10 @@ ft_index_to_string.tbl_spark <- function(x, input_col = NULL, output_col = NULL,
 }
 
 new_ml_index_to_string <- function(jobj) {
-  new_ml_transformer(jobj, subclass = "ml_index_to_string")
+  new_ml_transformer(jobj, class = "ml_index_to_string")
 }
 
-ml_validator_index_to_string <- function(.args) {
+validator_ml_index_to_string <- function(.args) {
   .args <- validate_args_transformer(.args)
   .args[["labels"]] <- cast_nullable_string_list(.args[["labels"]])
   .args
