@@ -1,14 +1,17 @@
 #' @rdname ft_lsh
 #' @export
 ft_minhash_lsh <- function(x, input_col = NULL, output_col = NULL,
-                           num_hash_tables = 1L, seed = NULL, dataset = NULL,
+                           num_hash_tables = 1L, seed = NULL,
                            uid = random_string("minhash_lsh_"), ...) {
+  check_dots_used()
   UseMethod("ft_minhash_lsh")
 }
 
+ml_minhash_lsh <- ft_minhash_lsh
+
 #' @export
 ft_minhash_lsh.spark_connection <- function(x, input_col = NULL, output_col = NULL,
-                                            num_hash_tables = 1L, seed = NULL, dataset = NULL,
+                                            num_hash_tables = 1L, seed = NULL,
                                             uid = random_string("minhash_lsh_"), ...) {
 
   spark_require_version(x, "2.1.0", "MinHashLSH")
@@ -21,26 +24,23 @@ ft_minhash_lsh.spark_connection <- function(x, input_col = NULL, output_col = NU
     uid = uid
   ) %>%
     c(rlang::dots_list(...)) %>%
-    ml_validator_minhash_lsh()
+    validator_ml_minhash_lsh()
 
-  jobj <- ml_new_transformer(
+  jobj <- spark_pipeline_stage(
     x, "org.apache.spark.ml.feature.MinHashLSH",
     input_col = .args[["input_col"]], output_col = .args[["output_col"]], uid = .args[["uid"]]
   ) %>%
     invoke("setNumHashTables", .args[["num_hash_tables"]]) %>%
-    maybe_set_param("setSeed", .args[["seed"]])
+    jobj_set_param("setSeed", .args[["seed"]])
 
   estimator <- new_ml_minhash_lsh(jobj)
 
-  if (is.null(dataset))
-    estimator
-  else
-    ml_fit(estimator, dataset)
+  estimator
 }
 
 #' @export
 ft_minhash_lsh.ml_pipeline <- function(x, input_col = NULL, output_col = NULL,
-                                       num_hash_tables = 1L, seed = NULL, dataset = NULL,
+                                       num_hash_tables = 1L, seed = NULL,
                                        uid = random_string("minhash_lsh_"), ...) {
 
   stage <- ft_minhash_lsh.spark_connection(
@@ -49,7 +49,6 @@ ft_minhash_lsh.ml_pipeline <- function(x, input_col = NULL, output_col = NULL,
     output_col = output_col,
     num_hash_tables = num_hash_tables,
     seed = seed,
-    dataset = dataset,
     uid = uid,
     ...
   )
@@ -59,7 +58,7 @@ ft_minhash_lsh.ml_pipeline <- function(x, input_col = NULL, output_col = NULL,
 
 #' @export
 ft_minhash_lsh.tbl_spark <- function(x, input_col = NULL, output_col = NULL,
-                                     num_hash_tables = 1L, seed = NULL, dataset = NULL,
+                                     num_hash_tables = 1L, seed = NULL,
                                      uid = random_string("minhash_lsh_"), ...) {
   stage <- ft_minhash_lsh.spark_connection(
     x = spark_connection(x),
@@ -67,7 +66,6 @@ ft_minhash_lsh.tbl_spark <- function(x, input_col = NULL, output_col = NULL,
     output_col = output_col,
     num_hash_tables = num_hash_tables,
     seed = seed,
-    dataset = dataset,
     uid = uid,
     ...
   )
@@ -79,7 +77,7 @@ ft_minhash_lsh.tbl_spark <- function(x, input_col = NULL, output_col = NULL,
 }
 
 new_ml_minhash_lsh <- function(jobj) {
-  new_ml_estimator(jobj, subclass = "ml_minhash_lsh")
+  new_ml_estimator(jobj, class = "ml_minhash_lsh")
 }
 
 new_ml_minhash_lsh_model <- function(jobj) {
@@ -87,10 +85,10 @@ new_ml_minhash_lsh_model <- function(jobj) {
     jobj,
     approx_nearest_neighbors = make_approx_nearest_neighbors(jobj),
     approx_similarity_join = make_approx_similarity_join(jobj),
-    subclass = "ml_minhash_lsh_model")
+    class = "ml_minhash_lsh_model")
 }
 
-ml_validator_minhash_lsh <- function(.args) {
+validator_ml_minhash_lsh <- function(.args) {
   .args <- validate_args_transformer(.args)
   .args[["num_hash_tables"]] <- cast_scalar_integer(.args[["num_hash_tables"]])
   .args[["seed"]] <- cast_nullable_scalar_integer(.args[["seed"]])
