@@ -44,18 +44,22 @@ ml_decision_tree_regressor.spark_connection <- function(x, formula = NULL, max_d
     features_col = .args[["features_col"]],
     label_col = .args[["label_col"]],
     prediction_col = .args[["prediction_col"]]
-  ) %>%
-    invoke("setCheckpointInterval", .args[["checkpoint_interval"]]) %>%
-    invoke("setImpurity", .args[["impurity"]]) %>%
-    invoke("setMaxBins", .args[["max_bins"]]) %>%
-    invoke("setMaxDepth", .args[["max_depth"]]) %>%
-    invoke("setMinInfoGain", .args[["min_info_gain"]]) %>%
-    invoke("setMinInstancesPerNode", .args[["min_instances_per_node"]]) %>%
-    invoke("setCacheNodeIds", .args[["cache_node_ids"]]) %>%
-    invoke("setMaxMemoryInMB", .args[["max_memory_in_mb"]]) %>%
-    jobj_set_param("setVarianceCol", .args[["variance_col"]], "2.0.0") %>%
-    jobj_set_param("setSeed", .args[["seed"]])
-
+  ) %>% (
+    function(obj) {
+      do.call(invoke,
+              c(obj, "%>%", Filter(function(x) !is.null(x),
+                            list(
+                                 list("setCheckpointInterval", .args[["checkpoint_interval"]]),
+                                 list("setImpurity", .args[["impurity"]]),
+                                 list("setMaxBins", .args[["max_bins"]]),
+                                 list("setMaxDepth", .args[["max_depth"]]),
+                                 list("setMinInfoGain", .args[["min_info_gain"]]),
+                                 list("setMinInstancesPerNode", .args[["min_instances_per_node"]]),
+                                 list("setCacheNodeIds", .args[["cache_node_ids"]]),
+                                 list("setMaxMemoryInMB", .args[["max_memory_in_mb"]]),
+                                 jobj_set_param_helper(obj, "setVarianceCol", .args[["variance_col"]], "2.0.0"),
+                                 jobj_set_param_helper(obj, "setSeed", .args[["seed"]])))))
+    })
   new_ml_decision_tree_regressor(jobj)
 }
 
