@@ -9,6 +9,7 @@ ml_gbt_regressor <- function(x, formula = NULL, max_iter = 20, max_depth = 5,
                              max_memory_in_mb = 256, features_col = "features",
                              label_col = "label", prediction_col = "prediction",
                              uid = random_string("gbt_regressor_"), ...) {
+  check_dots_used()
   UseMethod("ml_gbt_regressor")
 }
 
@@ -42,11 +43,12 @@ ml_gbt_regressor.spark_connection <- function(x, formula = NULL, max_iter = 20,
     prediction_col = prediction_col
   ) %>%
     c(rlang::dots_list(...)) %>%
-    ml_validator_gbt_regressor()
+    validator_ml_gbt_regressor()
 
-  jobj <- ml_new_predictor(
+  jobj <- spark_pipeline_stage(
     x, "org.apache.spark.ml.regression.GBTRegressor", uid,
-    .args[["features_col"]], .args[["label_col"]], .args[["prediction_col"]]
+    features_col = .args[["features_col"]], label_col = .args[["label_col"]],
+    prediction_col = .args[["prediction_col"]]
   ) %>%
     invoke("setCheckpointInterval", .args[["checkpoint_interval"]]) %>%
     invoke("setMaxBins", .args[["max_bins"]]) %>%
@@ -59,8 +61,8 @@ ml_gbt_regressor.spark_connection <- function(x, formula = NULL, max_iter = 20,
     invoke("setMaxIter", .args[["max_iter"]]) %>%
     invoke("setStepSize", .args[["step_size"]]) %>%
     invoke("setSubsamplingRate", .args[["subsampling_rate"]]) %>%
-    maybe_set_param("setFeatureSubsetStrategy", .args[["feature_subset_strategy"]], "2.3.0", "auto") %>%
-    maybe_set_param("setSeed", .args[["seed"]])
+    jobj_set_param("setFeatureSubsetStrategy", .args[["feature_subset_strategy"]], "2.3.0", "auto") %>%
+    jobj_set_param("setSeed", .args[["seed"]])
 
   new_ml_gbt_regressor(jobj)
 }
@@ -109,7 +111,7 @@ ml_gbt_regressor.tbl_spark <- function(x, formula = NULL, max_iter = 20, max_dep
                                        label_col = "label", prediction_col = "prediction",
                                        uid = random_string("gbt_regressor_"), response = NULL,
                                        features = NULL, ...) {
-  ml_formula_transformation()
+  formula <- ml_standardize_formula(formula, response, features)
 
   stage <- ml_gbt_regressor.spark_connection(
     x = spark_connection(x),
@@ -138,22 +140,20 @@ ml_gbt_regressor.tbl_spark <- function(x, formula = NULL, max_iter = 20, max_dep
     stage %>%
       ml_fit(x)
   } else {
-    ml_generate_ml_model(
-      x, stage, formula, features_col, label_col,
-      "regression", new_ml_model_gbt_regression
+    ml_construct_model_supervised(
+      new_ml_model_gbt_regression,
+      predictor = stage,
+      formula = formula,
+      dataset = x,
+      features_col = features_col,
+      label_col = label_col
     )
   }
 }
 
 # Validator
-ml_validator_gbt_regressor <- function(.args) {
-  .args <- .args %>%
-    ml_backwards_compatibility(
-      list(num.trees = "max_iter",
-           loss.type = "loss_type",
-           sample.rate = "subsampling_rate")
-    ) %>%
-    ml_validate_decision_tree_args()
+validator_ml_gbt_regressor <- function(.args) {
+  .args <- ml_validate_decision_tree_args(.args)
 
   .args[["max_iter"]] <- cast_scalar_integer(.args[["max_iter"]])
   .args[["step_size"]] <- cast_scalar_double(.args[["step_size"]])
@@ -166,15 +166,14 @@ ml_validator_gbt_regressor <- function(.args) {
 # Constructors
 
 new_ml_gbt_regressor <- function(jobj) {
-  new_ml_predictor(jobj, subclass = "ml_gbt_regressor")
+  new_ml_predictor(jobj, class = "ml_gbt_regressor")
 }
 
 new_ml_gbt_regression_model <- function(jobj) {
   new_ml_prediction_model(
     jobj,
     # `lazy val featureImportances`
-    feature_importances = function() try_null(read_spark_vector(jobj, "featureImportances")),
-    num_features = invoke(jobj, "numFeatures"),
+    feature_importances = possibly_null(~ read_spark_vector(jobj, "featureImportances")),
     # `lazy val totalNumNodes`
     total_num_nodes = invoke(jobj, "totalNumNodes"),
     # `def treeWeights`
@@ -182,7 +181,5 @@ new_ml_gbt_regression_model <- function(jobj) {
     # `def trees`
     trees = function() invoke(jobj, "trees") %>%
       purrr::map(new_ml_decision_tree_regression_model),
-    features_col = invoke(jobj, "getFeaturesCol"),
-    prediction_col = invoke(jobj, "getPredictionCol"),
-    subclass = "ml_gbt_regression_model")
+    class = "ml_gbt_regression_model")
 }
