@@ -30,11 +30,16 @@ ml_train_validation_split.spark_connection <- function(x, estimator = NULL, esti
   ml_new_validator(
     x, "org.apache.spark.ml.tuning.TrainValidationSplit", uid,
     .args[["estimator"]], .args[["evaluator"]], .args[["estimator_param_maps"]], .args[["seed"]]
-  ) %>%
-    invoke("setTrainRatio", .args[["train_ratio"]]) %>%
-    jobj_set_param("setCollectSubModels", .args[["collect_sub_models"]], "2.3.0", FALSE) %>%
-    jobj_set_param("setParallelism", .args[["parallelism"]], "2.3.0", 1) %>%
-    new_ml_train_validation_split()
+  ) %>% (
+    function(obj) {
+      do.call(invoke,
+              c(obj, "%>%", Filter(function(x) !is.null(x),
+                                   list(
+                                        list("setTrainRatio", .args[["train_ratio"]]),
+                                        jobj_set_param_helper(obj, "setCollectSubModels", .args[["collect_sub_models"]], "2.3.0", FALSE),
+                                        jobj_set_param_helper(obj, "setParallelism", .args[["parallelism"]], "2.3.0", 1)))))
+     }) %>%
+  new_ml_train_validation_split()
 }
 
 #' @export
@@ -97,8 +102,7 @@ new_ml_train_validation_split <- function(jobj) {
 new_ml_train_validation_split_model <- function(jobj) {
   validation_metrics <- invoke(jobj, "validationMetrics")
   metric_name <- jobj %>%
-    invoke("getEvaluator") %>%
-    invoke("getMetricName") %>%
+    invoke("%>%", list("getEvaluator"), list("getMetricName")) %>%
     rlang::sym()
   new_ml_tuning_model(
     jobj,
