@@ -12,8 +12,8 @@ NULL
 tidy.ml_model_isotonic_regression <- function(x,
                                                   ...){
 
-  tibble::data_frame(boundaries = x$model$boundaries(),
-                     predictions = x$model$predictions())
+  dplyr::tibble(boundaries = x$model$boundaries(),
+                predictions = x$model$predictions())
 
 }
 
